@@ -96,6 +96,9 @@ func newServer(f fs.Fs, templatePath string) *server {
 }
 
 func (s *server) Bind(router chi.Router) {
+	if m := auth.Auth(auth.Opt); m != nil {
+		router.Use(m)
+	}
 	router.Use(
 		middleware.SetHeader("Accept-Ranges", "bytes"),
 		middleware.SetHeader("Server", "rclone/"+fs.Version),
