@@ -3,8 +3,6 @@ package fs
 import (
 	"fmt"
 	"strings"
-
-	"github.com/pkg/errors"
 )
 
 // CutoffMode describes the possible delete modes in the config
@@ -40,7 +38,7 @@ func (m *CutoffMode) Set(s string) error {
 			return nil
 		}
 	}
-	return errors.Errorf("Unknown cutoff mode %q", s)
+	return fmt.Errorf("Unknown cutoff mode %q", s)
 }
 
 // Type of the value
@@ -52,7 +50,7 @@ func (m *CutoffMode) Type() string {
 func (m *CutoffMode) UnmarshalJSON(in []byte) error {
 	return UnmarshalJSONFlag(in, m, func(i int64) error {
 		if i < 0 || i >= int64(len(cutoffModeToString)) {
-			return errors.Errorf("Out of range cutoff mode %d", i)
+			return fmt.Errorf("Out of range cutoff mode %d", i)
 		}
 		*m = (CutoffMode)(i)
 		return nil
