@@ -4,7 +4,9 @@ import (
 	"crypto/md5"
 	"crypto/sha1"
 	"crypto/sha256"
+	"encoding/base64"
 	"encoding/hex"
+	"errors"
 	"fmt"
 	"hash"
 	"hash/crc32"
@@ -12,7 +14,6 @@ import (
 	"strings"
 
 	"github.com/jzelinskie/whirlpool"
-	"github.com/pkg/errors"
 )
 
 // Type indicates a standard hashing algorithm
@@ -92,8 +93,11 @@ func Supported() Set {
 }
 
 // Width returns the width in characters for any HashType
-func Width(hashType Type) int {
+func Width(hashType Type, base64Encoded bool) int {
 	if hash := type2hash[hashType]; hash != nil {
+		if base64Encoded {
+			return base64.URLEncoding.EncodedLen(hash.width / 2)
+		}
 		return hash.width
 	}
 	return 0
@@ -149,7 +153,7 @@ func (h *Type) Set(s string) error {
 		*h = hash.hashType
 		return nil
 	}
-	return errors.Errorf("Unknown hash type %q", s)
+	return fmt.Errorf("Unknown hash type %q", s)
 }
 
 // Type of the value
@@ -162,7 +166,7 @@ func (h Type) Type() string {
 // and this function must support all types.
 func fromTypes(set Set) (map[Type]hash.Hash, error) {
 	if !set.SubsetOf(Supported()) {
-		return nil, errors.Errorf("requested set %08x contains unknown hash types", int(set))
+		return nil, fmt.Errorf("requested set %08x contains unknown hash types", int(set))
 	}
 	hashers := map[Type]hash.Hash{}
 
@@ -243,6 +247,18 @@ func (m *MultiHasher) Sum(hashType Type) ([]byte, error) {
 	return h.Sum(nil), nil
 }
 
+// SumString returns the specified hash from the multihasher as a hex or base64 encoded string
+func (m *MultiHasher) SumString(hashType Type, base64Encoded bool) (string, error) {
+	sum, err := m.Sum(hashType)
+	if err != nil {
+		return "", err
+	}
+	if base64Encoded {
+		return base64.URLEncoding.EncodeToString(sum), nil
+	}
+	return hex.EncodeToString(sum), nil
+}
+
 // Size returns the number of bytes written
 func (m *MultiHasher) Size() int64 {
 	return m.size
