@@ -23,6 +23,7 @@ import (
 	"bytes"
 	"context"
 	"crypto/rand"
+	"errors"
 	"fmt"
 	"io"
 	"io/ioutil"
@@ -34,7 +35,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/pkg/errors"
 	_ "github.com/rclone/rclone/backend/all" // import all backends
 	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/accounting"
@@ -80,7 +80,7 @@ func TestLsd(t *testing.T) {
 	defer r.Finalise()
 	file1 := r.WriteObject(ctx, "sub dir/hello world", "hello world", t1)
 
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckRemoteItems(t, file1)
 
 	var buf bytes.Buffer
 	err := operations.ListDir(ctx, r.Fremote, &buf)
@@ -96,7 +96,7 @@ func TestLs(t *testing.T) {
 	file1 := r.WriteBoth(ctx, "potato2", "------------------------------------------------------------", t1)
 	file2 := r.WriteBoth(ctx, "empty space", "-", t2)
 
-	fstest.CheckItems(t, r.Fremote, file1, file2)
+	r.CheckRemoteItems(t, file1, file2)
 
 	var buf bytes.Buffer
 	err := operations.List(ctx, r.Fremote, &buf)
@@ -114,7 +114,7 @@ func TestLsWithFilesFrom(t *testing.T) {
 	file1 := r.WriteBoth(ctx, "potato2", "------------------------------------------------------------", t1)
 	file2 := r.WriteBoth(ctx, "empty space", "-", t2)
 
-	fstest.CheckItems(t, r.Fremote, file1, file2)
+	r.CheckRemoteItems(t, file1, file2)
 
 	// Set the --files-from equivalent
 	f, err := filter.NewFilter(nil)
@@ -146,7 +146,7 @@ func TestLsLong(t *testing.T) {
 	file1 := r.WriteBoth(ctx, "potato2", "------------------------------------------------------------", t1)
 	file2 := r.WriteBoth(ctx, "empty space", "-", t2)
 
-	fstest.CheckItems(t, r.Fremote, file1, file2)
+	r.CheckRemoteItems(t, file1, file2)
 
 	var buf bytes.Buffer
 	err := operations.ListLong(ctx, r.Fremote, &buf)
@@ -189,7 +189,7 @@ func TestHashSums(t *testing.T) {
 	file1 := r.WriteBoth(ctx, "potato2", "------------------------------------------------------------", t1)
 	file2 := r.WriteBoth(ctx, "empty space", "-", t2)
 
-	fstest.CheckItems(t, r.Fremote, file1, file2)
+	r.CheckRemoteItems(t, file1, file2)
 
 	hashes := r.Fremote.Hashes()
 
@@ -316,6 +316,52 @@ func TestHashSumsWithErrors(t *testing.T) {
 	// TODO mock an unreadable file
 }
 
+func TestHashStream(t *testing.T) {
+	reader := strings.NewReader("")
+	in := ioutil.NopCloser(reader)
+	out := &bytes.Buffer{}
+	for _, test := range []struct {
+		input      string
+		ht         hash.Type
+		wantHex    string
+		wantBase64 string
+	}{
+		{
+			input:      "",
+			ht:         hash.MD5,
+			wantHex:    "d41d8cd98f00b204e9800998ecf8427e  -\n",
+			wantBase64: "1B2M2Y8AsgTpgAmY7PhCfg==  -\n",
+		},
+		{
+			input:      "",
+			ht:         hash.SHA1,
+			wantHex:    "da39a3ee5e6b4b0d3255bfef95601890afd80709  -\n",
+			wantBase64: "2jmj7l5rSw0yVb_vlWAYkK_YBwk=  -\n",
+		},
+		{
+			input:      "Hello world!",
+			ht:         hash.MD5,
+			wantHex:    "86fb269d190d2c85f6e0468ceca42a20  -\n",
+			wantBase64: "hvsmnRkNLIX24EaM7KQqIA==  -\n",
+		},
+		{
+			input:      "Hello world!",
+			ht:         hash.SHA1,
+			wantHex:    "d3486ae9136e7856bc42212385ea797094475802  -\n",
+			wantBase64: "00hq6RNueFa8QiEjhep5cJRHWAI=  -\n",
+		},
+	} {
+		reader.Reset(test.input)
+		require.NoError(t, operations.HashSumStream(test.ht, false, in, out))
+		assert.Equal(t, test.wantHex, out.String())
+		_, _ = reader.Seek(0, io.SeekStart)
+		out.Reset()
+		require.NoError(t, operations.HashSumStream(test.ht, true, in, out))
+		assert.Equal(t, test.wantBase64, out.String())
+		out.Reset()
+	}
+}
+
 func TestSuffixName(t *testing.T) {
 	ctx := context.Background()
 	ctx, ci := fs.AddConfig(ctx)
@@ -350,7 +396,7 @@ func TestCount(t *testing.T) {
 	file2 := r.WriteBoth(ctx, "empty space", "-", t2)
 	file3 := r.WriteBoth(ctx, "sub dir/potato3", "hello", t2)
 
-	fstest.CheckItems(t, r.Fremote, file1, file2, file3)
+	r.CheckRemoteItems(t, file1, file2, file3)
 
 	// Check the MaxDepth too
 	ci.MaxDepth = 1
@@ -372,11 +418,11 @@ func TestDelete(t *testing.T) {
 	file1 := r.WriteObject(ctx, "small", "1234567890", t2)                                                                                           // 10 bytes
 	file2 := r.WriteObject(ctx, "medium", "------------------------------------------------------------", t1)                                        // 60 bytes
 	file3 := r.WriteObject(ctx, "large", "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA", t1) // 100 bytes
-	fstest.CheckItems(t, r.Fremote, file1, file2, file3)
+	r.CheckRemoteItems(t, file1, file2, file3)
 
 	err = operations.Delete(ctx, r.Fremote)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Fremote, file3)
+	r.CheckRemoteItems(t, file3)
 }
 
 func TestRetry(t *testing.T) {
@@ -413,7 +459,7 @@ func TestCat(t *testing.T) {
 	file1 := r.WriteBoth(ctx, "file1", "ABCDEFGHIJ", t1)
 	file2 := r.WriteBoth(ctx, "file2", "012345678", t2)
 
-	fstest.CheckItems(t, r.Fremote, file1, file2)
+	r.CheckRemoteItems(t, file1, file2)
 
 	for _, test := range []struct {
 		offset int64
@@ -678,7 +724,7 @@ func TestCopyURL(t *testing.T) {
 	file1 := r.WriteFile("file1", contents, t1)
 	file2 := r.WriteFile("file2", contents, t1)
 	r.Mkdir(ctx, r.Fremote)
-	fstest.CheckItems(t, r.Fremote)
+	r.CheckRemoteItems(t)
 
 	// check when reading from regular HTTP server
 	status := 0
@@ -773,28 +819,28 @@ func TestMoveFile(t *testing.T) {
 	defer r.Finalise()
 
 	file1 := r.WriteFile("file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	file2 := file1
 	file2.Path = "sub/file2"
 
 	err := operations.MoveFile(ctx, r.Fremote, r.Flocal, file2.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t)
+	r.CheckRemoteItems(t, file2)
 
 	r.WriteFile("file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	err = operations.MoveFile(ctx, r.Fremote, r.Flocal, file2.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t)
+	r.CheckRemoteItems(t, file2)
 
 	err = operations.MoveFile(ctx, r.Fremote, r.Fremote, file2.Path, file2.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t)
+	r.CheckRemoteItems(t, file2)
 }
 
 func TestMoveFileWithIgnoreExisting(t *testing.T) {
@@ -803,24 +849,24 @@ func TestMoveFileWithIgnoreExisting(t *testing.T) {
 	r := fstest.NewRun(t)
 	defer r.Finalise()
 	file1 := r.WriteFile("file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	ci.IgnoreExisting = true
 
 	err := operations.MoveFile(ctx, r.Fremote, r.Flocal, file1.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckLocalItems(t)
+	r.CheckRemoteItems(t, file1)
 
 	// Recreate file with updated content
 	file1b := r.WriteFile("file1", "file1 modified", t2)
-	fstest.CheckItems(t, r.Flocal, file1b)
+	r.CheckLocalItems(t, file1b)
 
 	// Ensure modified file did not transfer and was not deleted
 	err = operations.MoveFile(ctx, r.Fremote, r.Flocal, file1.Path, file1b.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal, file1b)
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckLocalItems(t, file1b)
+	r.CheckRemoteItems(t, file1)
 }
 
 func TestCaseInsensitiveMoveFile(t *testing.T) {
@@ -832,31 +878,31 @@ func TestCaseInsensitiveMoveFile(t *testing.T) {
 	}
 
 	file1 := r.WriteFile("file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	file2 := file1
 	file2.Path = "sub/file2"
 
 	err := operations.MoveFile(ctx, r.Fremote, r.Flocal, file2.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t)
+	r.CheckRemoteItems(t, file2)
 
 	r.WriteFile("file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	err = operations.MoveFile(ctx, r.Fremote, r.Flocal, file2.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t)
+	r.CheckRemoteItems(t, file2)
 
 	file2Capitalized := file2
 	file2Capitalized.Path = "sub/File2"
 
 	err = operations.MoveFile(ctx, r.Fremote, r.Fremote, file2Capitalized.Path, file2.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
-	fstest.CheckItems(t, r.Fremote, file2Capitalized)
+	r.CheckLocalItems(t)
+	r.CheckRemoteItems(t, file2Capitalized)
 }
 
 func TestMoveFileBackupDir(t *testing.T) {
@@ -871,16 +917,16 @@ func TestMoveFileBackupDir(t *testing.T) {
 	ci.BackupDir = r.FremoteName + "/backup"
 
 	file1 := r.WriteFile("dst/file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	file1old := r.WriteObject(ctx, "dst/file1", "file1 contents old", t1)
-	fstest.CheckItems(t, r.Fremote, file1old)
+	r.CheckRemoteItems(t, file1old)
 
 	err := operations.MoveFile(ctx, r.Fremote, r.Flocal, file1.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal)
+	r.CheckLocalItems(t)
 	file1old.Path = "backup/dst/file1"
-	fstest.CheckItems(t, r.Fremote, file1old, file1)
+	r.CheckRemoteItems(t, file1old, file1)
 }
 
 func TestCopyFile(t *testing.T) {
@@ -889,25 +935,25 @@ func TestCopyFile(t *testing.T) {
 	defer r.Finalise()
 
 	file1 := r.WriteFile("file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	file2 := file1
 	file2.Path = "sub/file2"
 
 	err := operations.CopyFile(ctx, r.Fremote, r.Flocal, file2.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal, file1)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t, file1)
+	r.CheckRemoteItems(t, file2)
 
 	err = operations.CopyFile(ctx, r.Fremote, r.Flocal, file2.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal, file1)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t, file1)
+	r.CheckRemoteItems(t, file2)
 
 	err = operations.CopyFile(ctx, r.Fremote, r.Fremote, file2.Path, file2.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal, file1)
-	fstest.CheckItems(t, r.Fremote, file2)
+	r.CheckLocalItems(t, file1)
+	r.CheckRemoteItems(t, file2)
 }
 
 func TestCopyFileBackupDir(t *testing.T) {
@@ -922,16 +968,16 @@ func TestCopyFileBackupDir(t *testing.T) {
 	ci.BackupDir = r.FremoteName + "/backup"
 
 	file1 := r.WriteFile("dst/file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	file1old := r.WriteObject(ctx, "dst/file1", "file1 contents old", t1)
-	fstest.CheckItems(t, r.Fremote, file1old)
+	r.CheckRemoteItems(t, file1old)
 
 	err := operations.CopyFile(ctx, r.Fremote, r.Flocal, file1.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 	file1old.Path = "backup/dst/file1"
-	fstest.CheckItems(t, r.Fremote, file1old, file1)
+	r.CheckRemoteItems(t, file1old, file1)
 }
 
 // Test with CompareDest set
@@ -947,7 +993,7 @@ func TestCopyFileCompareDest(t *testing.T) {
 
 	// check empty dest, empty compare
 	file1 := r.WriteFile("one", "one", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file1.Path, file1.Path)
 	require.NoError(t, err)
@@ -955,12 +1001,12 @@ func TestCopyFileCompareDest(t *testing.T) {
 	file1dst := file1
 	file1dst.Path = "dst/one"
 
-	fstest.CheckItems(t, r.Fremote, file1dst)
+	r.CheckRemoteItems(t, file1dst)
 
 	// check old dest, empty compare
 	file1b := r.WriteFile("one", "onet2", t2)
-	fstest.CheckItems(t, r.Fremote, file1dst)
-	fstest.CheckItems(t, r.Flocal, file1b)
+	r.CheckRemoteItems(t, file1dst)
+	r.CheckLocalItems(t, file1b)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file1b.Path, file1b.Path)
 	require.NoError(t, err)
@@ -968,41 +1014,41 @@ func TestCopyFileCompareDest(t *testing.T) {
 	file1bdst := file1b
 	file1bdst.Path = "dst/one"
 
-	fstest.CheckItems(t, r.Fremote, file1bdst)
+	r.CheckRemoteItems(t, file1bdst)
 
 	// check old dest, new compare
 	file3 := r.WriteObject(ctx, "dst/one", "one", t1)
 	file2 := r.WriteObject(ctx, "CompareDest/one", "onet2", t2)
 	file1c := r.WriteFile("one", "onet2", t2)
-	fstest.CheckItems(t, r.Fremote, file2, file3)
-	fstest.CheckItems(t, r.Flocal, file1c)
+	r.CheckRemoteItems(t, file2, file3)
+	r.CheckLocalItems(t, file1c)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file1c.Path, file1c.Path)
 	require.NoError(t, err)
 
-	fstest.CheckItems(t, r.Fremote, file2, file3)
+	r.CheckRemoteItems(t, file2, file3)
 
 	// check empty dest, new compare
 	file4 := r.WriteObject(ctx, "CompareDest/two", "two", t2)
 	file5 := r.WriteFile("two", "two", t2)
-	fstest.CheckItems(t, r.Fremote, file2, file3, file4)
-	fstest.CheckItems(t, r.Flocal, file1c, file5)
+	r.CheckRemoteItems(t, file2, file3, file4)
+	r.CheckLocalItems(t, file1c, file5)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file5.Path, file5.Path)
 	require.NoError(t, err)
 
-	fstest.CheckItems(t, r.Fremote, file2, file3, file4)
+	r.CheckRemoteItems(t, file2, file3, file4)
 
 	// check new dest, new compare
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file5.Path, file5.Path)
 	require.NoError(t, err)
 
-	fstest.CheckItems(t, r.Fremote, file2, file3, file4)
+	r.CheckRemoteItems(t, file2, file3, file4)
 
 	// check empty dest, old compare
 	file5b := r.WriteFile("two", "twot3", t3)
-	fstest.CheckItems(t, r.Fremote, file2, file3, file4)
-	fstest.CheckItems(t, r.Flocal, file1c, file5b)
+	r.CheckRemoteItems(t, file2, file3, file4)
+	r.CheckLocalItems(t, file1c, file5b)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file5b.Path, file5b.Path)
 	require.NoError(t, err)
@@ -1010,7 +1056,7 @@ func TestCopyFileCompareDest(t *testing.T) {
 	file5bdst := file5b
 	file5bdst.Path = "dst/two"
 
-	fstest.CheckItems(t, r.Fremote, file2, file3, file4, file5bdst)
+	r.CheckRemoteItems(t, file2, file3, file4, file5bdst)
 }
 
 // Test with CopyDest set
@@ -1031,7 +1077,7 @@ func TestCopyFileCopyDest(t *testing.T) {
 
 	// check empty dest, empty copy
 	file1 := r.WriteFile("one", "one", t1)
-	fstest.CheckItems(t, r.Flocal, file1)
+	r.CheckLocalItems(t, file1)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file1.Path, file1.Path)
 	require.NoError(t, err)
@@ -1039,12 +1085,12 @@ func TestCopyFileCopyDest(t *testing.T) {
 	file1dst := file1
 	file1dst.Path = "dst/one"
 
-	fstest.CheckItems(t, r.Fremote, file1dst)
+	r.CheckRemoteItems(t, file1dst)
 
 	// check old dest, empty copy
 	file1b := r.WriteFile("one", "onet2", t2)
-	fstest.CheckItems(t, r.Fremote, file1dst)
-	fstest.CheckItems(t, r.Flocal, file1b)
+	r.CheckRemoteItems(t, file1dst)
+	r.CheckLocalItems(t, file1b)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file1b.Path, file1b.Path)
 	require.NoError(t, err)
@@ -1052,7 +1098,7 @@ func TestCopyFileCopyDest(t *testing.T) {
 	file1bdst := file1b
 	file1bdst.Path = "dst/one"
 
-	fstest.CheckItems(t, r.Fremote, file1bdst)
+	r.CheckRemoteItems(t, file1bdst)
 
 	// check old dest, new copy, backup-dir
 
@@ -1061,8 +1107,8 @@ func TestCopyFileCopyDest(t *testing.T) {
 	file3 := r.WriteObject(ctx, "dst/one", "one", t1)
 	file2 := r.WriteObject(ctx, "CopyDest/one", "onet2", t2)
 	file1c := r.WriteFile("one", "onet2", t2)
-	fstest.CheckItems(t, r.Fremote, file2, file3)
-	fstest.CheckItems(t, r.Flocal, file1c)
+	r.CheckRemoteItems(t, file2, file3)
+	r.CheckLocalItems(t, file1c)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file1c.Path, file1c.Path)
 	require.NoError(t, err)
@@ -1071,14 +1117,14 @@ func TestCopyFileCopyDest(t *testing.T) {
 	file2dst.Path = "dst/one"
 	file3.Path = "BackupDir/one"
 
-	fstest.CheckItems(t, r.Fremote, file2, file2dst, file3)
+	r.CheckRemoteItems(t, file2, file2dst, file3)
 	ci.BackupDir = ""
 
 	// check empty dest, new copy
 	file4 := r.WriteObject(ctx, "CopyDest/two", "two", t2)
 	file5 := r.WriteFile("two", "two", t2)
-	fstest.CheckItems(t, r.Fremote, file2, file2dst, file3, file4)
-	fstest.CheckItems(t, r.Flocal, file1c, file5)
+	r.CheckRemoteItems(t, file2, file2dst, file3, file4)
+	r.CheckLocalItems(t, file1c, file5)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file5.Path, file5.Path)
 	require.NoError(t, err)
@@ -1086,19 +1132,19 @@ func TestCopyFileCopyDest(t *testing.T) {
 	file4dst := file4
 	file4dst.Path = "dst/two"
 
-	fstest.CheckItems(t, r.Fremote, file2, file2dst, file3, file4, file4dst)
+	r.CheckRemoteItems(t, file2, file2dst, file3, file4, file4dst)
 
 	// check new dest, new copy
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file5.Path, file5.Path)
 	require.NoError(t, err)
 
-	fstest.CheckItems(t, r.Fremote, file2, file2dst, file3, file4, file4dst)
+	r.CheckRemoteItems(t, file2, file2dst, file3, file4, file4dst)
 
 	// check empty dest, old copy
 	file6 := r.WriteObject(ctx, "CopyDest/three", "three", t2)
 	file7 := r.WriteFile("three", "threet3", t3)
-	fstest.CheckItems(t, r.Fremote, file2, file2dst, file3, file4, file4dst, file6)
-	fstest.CheckItems(t, r.Flocal, file1c, file5, file7)
+	r.CheckRemoteItems(t, file2, file2dst, file3, file4, file4dst, file6)
+	r.CheckLocalItems(t, file1c, file5, file7)
 
 	err = operations.CopyFile(ctx, fdst, r.Flocal, file7.Path, file7.Path)
 	require.NoError(t, err)
@@ -1106,7 +1152,7 @@ func TestCopyFileCopyDest(t *testing.T) {
 	file7dst := file7
 	file7dst.Path = "dst/three"
 
-	fstest.CheckItems(t, r.Fremote, file2, file2dst, file3, file4, file4dst, file6, file7dst)
+	r.CheckRemoteItems(t, file2, file2dst, file3, file4, file4dst, file6, file7dst)
 }
 
 // testFsInfo is for unit testing fs.Info
@@ -1468,7 +1514,7 @@ func TestRcat(t *testing.T) {
 
 		file1 := fstest.NewItem(path1, data1, t1)
 		file2 := fstest.NewItem(path2, data2, t2)
-		fstest.CheckItems(t, r.Fremote, file1, file2)
+		r.CheckRemoteItems(t, file1, file2)
 	}
 
 	for i := 0; i < 4; i++ {
@@ -1504,7 +1550,7 @@ func TestRcatSize(t *testing.T) {
 	assert.Equal(t, file2.Path, obj.Remote())
 
 	// Check files exist
-	fstest.CheckItems(t, r.Fremote, file1, file2)
+	r.CheckRemoteItems(t, file1, file2)
 }
 
 func TestCopyFileMaxTransfer(t *testing.T) {
@@ -1535,8 +1581,8 @@ func TestCopyFileMaxTransfer(t *testing.T) {
 	accounting.Stats(ctx).ResetCounters()
 	err = operations.CopyFile(ctx, r.Fremote, r.Flocal, file1.Path, file1.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal, file1, file2, file3, file4)
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckLocalItems(t, file1, file2, file3, file4)
+	r.CheckRemoteItems(t, file1)
 
 	// file2: show a large file does not get transferred
 	accounting.Stats(ctx).ResetCounters()
@@ -1544,8 +1590,8 @@ func TestCopyFileMaxTransfer(t *testing.T) {
 	require.NotNil(t, err, "Did not get expected max transfer limit error")
 	assert.Contains(t, err.Error(), "Max transfer limit reached")
 	assert.True(t, fserrors.IsFatalError(err), fmt.Sprintf("Not fatal error: %v: %#v:", err, err))
-	fstest.CheckItems(t, r.Flocal, file1, file2, file3, file4)
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckLocalItems(t, file1, file2, file3, file4)
+	r.CheckRemoteItems(t, file1)
 
 	// Cutoff mode: Cautious
 	ci.CutoffMode = fs.CutoffModeCautious
@@ -1556,8 +1602,8 @@ func TestCopyFileMaxTransfer(t *testing.T) {
 	require.NotNil(t, err)
 	assert.Contains(t, err.Error(), "Max transfer limit reached")
 	assert.True(t, fserrors.IsNoRetryError(err))
-	fstest.CheckItems(t, r.Flocal, file1, file2, file3, file4)
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckLocalItems(t, file1, file2, file3, file4)
+	r.CheckRemoteItems(t, file1)
 
 	if strings.HasPrefix(r.Fremote.Name(), "TestChunker") {
 		t.Log("skipping remainder of test for chunker as it involves multiple transfers")
@@ -1571,8 +1617,8 @@ func TestCopyFileMaxTransfer(t *testing.T) {
 	accounting.Stats(ctx).ResetCounters()
 	err = operations.CopyFile(ctx, r.Fremote, r.Flocal, file4.Path, file4.Path)
 	require.NoError(t, err)
-	fstest.CheckItems(t, r.Flocal, file1, file2, file3, file4)
-	fstest.CheckItems(t, r.Fremote, file1, file4)
+	r.CheckLocalItems(t, file1, file2, file3, file4)
+	r.CheckRemoteItems(t, file1, file4)
 }
 
 func TestTouchDir(t *testing.T) {
@@ -1587,18 +1633,18 @@ func TestTouchDir(t *testing.T) {
 	file1 := r.WriteBoth(ctx, "potato2", "------------------------------------------------------------", t1)
 	file2 := r.WriteBoth(ctx, "empty space", "-", t2)
 	file3 := r.WriteBoth(ctx, "sub dir/potato3", "hello", t2)
-	fstest.CheckItems(t, r.Fremote, file1, file2, file3)
+	r.CheckRemoteItems(t, file1, file2, file3)
 
 	timeValue := time.Date(2010, 9, 8, 7, 6, 5, 4, time.UTC)
-	err := operations.TouchDir(ctx, r.Fremote, timeValue, true)
+	err := operations.TouchDir(ctx, r.Fremote, "", timeValue, true)
 	require.NoError(t, err)
 	if accounting.Stats(ctx).GetErrors() != 0 {
-		err = errors.Cause(accounting.Stats(ctx).GetLastError())
-		require.True(t, err == fs.ErrorCantSetModTime || err == fs.ErrorCantSetModTimeWithoutDelete)
+		err = accounting.Stats(ctx).GetLastError()
+		require.True(t, errors.Is(err, fs.ErrorCantSetModTime) || errors.Is(err, fs.ErrorCantSetModTimeWithoutDelete))
 	} else {
 		file1.ModTime = timeValue
 		file2.ModTime = timeValue
 		file3.ModTime = timeValue
-		fstest.CheckItems(t, r.Fremote, file1, file2, file3)
+		r.CheckRemoteItems(t, file1, file2, file3)
 	}
 }
