@@ -1,9 +1,8 @@
 package rest
 
 import (
+	"fmt"
 	"net/url"
-
-	"github.com/pkg/errors"
 )
 
 // URLJoin joins a URL and a path returning a new URL
@@ -12,7 +11,7 @@ import (
 func URLJoin(base *url.URL, path string) (*url.URL, error) {
 	rel, err := url.Parse(path)
 	if err != nil {
-		return nil, errors.Wrapf(err, "Error parsing %q as URL", path)
+		return nil, fmt.Errorf("Error parsing %q as URL: %w", path, err)
 	}
 	return base.ResolveReference(rel), nil
 }
