@@ -38,6 +38,9 @@ import (
 	_ "github.com/rclone/rclone/fs/operations" // import operations/* rc commands
 	_ "github.com/rclone/rclone/fs/sync"       // import sync/*
 	_ "github.com/rclone/rclone/lib/plugin"    // import plugins
+	_ "github.com/rclone/rclone/cmd/mount"     // import mount
+	_ "github.com/rclone/rclone/cmd/mount2"    // import mount2
+	_ "github.com/rclone/rclone/cmd/cmount"    // import cmount
 )
 
 // RcloneInitialize initializes rclone as a library
