@@ -3,6 +3,7 @@ package vfscache
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"os"
 	"path"
@@ -14,13 +15,13 @@ import (
 	"time"
 
 	sysdnotify "github.com/iguanesolutions/go-systemd/v5/notify"
-	"github.com/pkg/errors"
 	"github.com/rclone/rclone/fs"
 	fscache "github.com/rclone/rclone/fs/cache"
 	"github.com/rclone/rclone/fs/config"
 	"github.com/rclone/rclone/fs/fserrors"
 	"github.com/rclone/rclone/fs/hash"
 	"github.com/rclone/rclone/fs/operations"
+	"github.com/rclone/rclone/fs/rc"
 	"github.com/rclone/rclone/lib/encoder"
 	"github.com/rclone/rclone/lib/file"
 	"github.com/rclone/rclone/vfs/vfscache/writeback"
@@ -130,7 +131,7 @@ func New(ctx context.Context, fremote fs.Fs, opt *vfscommon.Options, avFn AddVir
 	// load in the cache and metadata off disk
 	err = c.reload(ctx)
 	if err != nil {
-		return nil, errors.Wrap(err, "failed to load cache")
+		return nil, fmt.Errorf("failed to load cache: %w", err)
 	}
 
 	// Remove any empty directories
@@ -145,6 +146,29 @@ func New(ctx context.Context, fremote fs.Fs, opt *vfscommon.Options, avFn AddVir
 	return c, nil
 }
 
+// Stats returns info about the Cache
+func (c *Cache) Stats() (out rc.Params) {
+	out = make(rc.Params)
+	// read only - no locking needed to read these
+	out["path"] = c.root
+	out["pathMeta"] = c.metaRoot
+	out["hashType"] = c.hashType
+
+	uploadsInProgress, uploadsQueued := c.writeback.Stats()
+	out["uploadsInProgress"] = uploadsInProgress
+	out["uploadsQueued"] = uploadsQueued
+
+	c.mu.Lock()
+	defer c.mu.Unlock()
+
+	out["files"] = len(c.item)
+	out["erroredFiles"] = len(c.errItems)
+	out["bytesUsed"] = c.used
+	out["outOfSpace"] = c.outOfSpace
+
+	return out
+}
+
 // createDir creates a directory path, along with any necessary parents
 func createDir(dir string) error {
 	return file.MkdirAll(dir, 0700)
@@ -160,9 +184,9 @@ func createRootDir(parentOSPath string, name string, relativeDirOSPath string) (
 // createRootDirs creates all cache root directories
 func createRootDirs(parentOSPath string, relativeDirOSPath string) (dataOSPath string, metaOSPath string, err error) {
 	if dataOSPath, err = createRootDir(parentOSPath, "vfs", relativeDirOSPath); err != nil {
-		err = errors.Wrap(err, "failed to create data cache directory")
+		err = fmt.Errorf("failed to create data cache directory: %w", err)
 	} else if metaOSPath, err = createRootDir(parentOSPath, "vfsMeta", relativeDirOSPath); err != nil {
-		err = errors.Wrap(err, "failed to create metadata cache directory")
+		err = fmt.Errorf("failed to create metadata cache directory: %w", err)
 	}
 	return
 }
@@ -172,18 +196,17 @@ func createRootDirs(parentOSPath string, relativeDirOSPath string) (dataOSPath s
 // Returns an os path for the data cache file.
 func (c *Cache) createItemDir(name string) (string, error) {
 	parent := vfscommon.FindParent(name)
-	leaf := filepath.Base(name)
 	parentPath := c.toOSPath(parent)
 	err := createDir(parentPath)
 	if err != nil {
-		return "", errors.Wrap(err, "failed to create data cache item directory")
+		return "", fmt.Errorf("failed to create data cache item directory: %w", err)
 	}
 	parentPathMeta := c.toOSPathMeta(parent)
 	err = createDir(parentPathMeta)
 	if err != nil {
-		return "", errors.Wrap(err, "failed to create metadata cache item directory")
+		return "", fmt.Errorf("failed to create metadata cache item directory: %w", err)
 	}
-	return filepath.Join(parentPath, leaf), nil
+	return c.toOSPath(name), nil
 }
 
 // getBackend gets a backend for a cache root dir
@@ -195,9 +218,9 @@ func getBackend(ctx context.Context, parentPath string, name string, relativeDir
 // getBackends gets backends for all cache root dirs
 func getBackends(ctx context.Context, parentPath string, relativeDirPath string) (fdata fs.Fs, fmeta fs.Fs, err error) {
 	if fdata, err = getBackend(ctx, parentPath, "vfs", relativeDirPath); err != nil {
-		err = errors.Wrap(err, "failed to get data cache backend")
+		err = fmt.Errorf("failed to get data cache backend: %w", err)
 	} else if fmeta, err = getBackend(ctx, parentPath, "vfsMeta", relativeDirPath); err != nil {
-		err = errors.Wrap(err, "failed to get metadata cache backend")
+		err = fmt.Errorf("failed to get metadata cache backend: %w", err)
 	}
 	return
 }
@@ -342,32 +365,32 @@ func rename(osOldPath, osNewPath string) error {
 		if os.IsNotExist(err) {
 			return nil
 		}
-		return errors.Wrapf(err, "Failed to stat source: %s", osOldPath)
+		return fmt.Errorf("Failed to stat source: %s: %w", osOldPath, err)
 	}
 	if !sfi.Mode().IsRegular() {
 		// cannot copy non-regular files (e.g., directories, symlinks, devices, etc.)
-		return errors.Errorf("Non-regular source file: %s (%q)", sfi.Name(), sfi.Mode().String())
+		return fmt.Errorf("Non-regular source file: %s (%q)", sfi.Name(), sfi.Mode().String())
 	}
 	dfi, err := os.Stat(osNewPath)
 	if err != nil {
 		if !os.IsNotExist(err) {
-			return errors.Wrapf(err, "Failed to stat destination: %s", osNewPath)
+			return fmt.Errorf("Failed to stat destination: %s: %w", osNewPath, err)
 		}
 		parent := vfscommon.OsFindParent(osNewPath)
 		err = createDir(parent)
 		if err != nil {
-			return errors.Wrapf(err, "Failed to create parent dir: %s", parent)
+			return fmt.Errorf("Failed to create parent dir: %s: %w", parent, err)
 		}
 	} else {
 		if !(dfi.Mode().IsRegular()) {
-			return errors.Errorf("Non-regular destination file: %s (%q)", dfi.Name(), dfi.Mode().String())
+			return fmt.Errorf("Non-regular destination file: %s (%q)", dfi.Name(), dfi.Mode().String())
 		}
 		if os.SameFile(sfi, dfi) {
 			return nil
 		}
 	}
 	if err = os.Rename(osOldPath, osNewPath); err != nil {
-		return errors.Wrapf(err, "Failed to rename in cache: %s to %s", osOldPath, osNewPath)
+		return fmt.Errorf("Failed to rename in cache: %s to %s: %w", osOldPath, osNewPath, err)
 	}
 	return nil
 }
@@ -478,7 +501,7 @@ func (c *Cache) walk(dir string, fn func(osPath string, fi os.FileInfo, name str
 		// Find path relative to the cache root
 		name, err := filepath.Rel(dir, osPath)
 		if err != nil {
-			return errors.Wrap(err, "filepath.Rel failed in walk")
+			return fmt.Errorf("filepath.Rel failed in walk: %w", err)
 		}
 		if name == "." {
 			name = ""
@@ -511,7 +534,7 @@ func (c *Cache) reload(ctx context.Context) error {
 			return nil
 		})
 		if err != nil {
-			return errors.Wrapf(err, "failed to walk cache %q", dir)
+			return fmt.Errorf("failed to walk cache %q: %w", dir, err)
 		}
 	}
 	return nil
